pub struct StreamConfig { /* fields omitted */ }Expand description
Gets data ready to begin recording
pub fn new(silence_level: i32) -> Self[src]
Creates a new stream configuration:
Returns the device in use:
Returns the silence level
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.